package BK::ServFunc::Utils;

require 5.002;
use BK::Composer;
require BK::Batcher;
use POSIX;

sub register {
    return {
	"release"	  => { func => \&BK::ServFunc::Utils::release, },
	"server-ForgetIt" => { func => \&BK::ServFunc::Utils::serverForgetIt, },
	"user-runbatch"   => { func => \&BK::ServFunc::Utils::userRunBatch,
			       shorthelp => "Process recurring transactions",
			       help      => "
    runbatch -- Process recurring transactions

    bk runbatch [ -d date ] [ -m mID ] [ cmds ... ]

        Runbatch may be used to force the processing of recurring
        transaction or to run a memorized transaction.  Optional
        commands may be added on the command line and they will
        evaluated before each transaction's commands.

        Use the -m option to specify the Recurrence ID of a
        memorized transaction (ie. NextDate is empty and Interval
        is 'never').  Use the -d option to specify the date to run
        under.  This may be useful, for example, to get ahead in
        your work.

        It should be noted that the server will process recurring
        transactions automatically and periodically.
",

			     },
    }
}

sub release {
    my ($server, $table, $args) = @_;
    $server->{_RELEASED} = 1;
}

sub serverForgetIt {
    my ($server, $table, $args) = @_;
    $server->release();
}

sub userRunBatch {
    my ($server, $table, $args) = @_;
    BK::Batcher->new($server)->runBatch($args);
    $server->release();
}

1;
